module Geography
  class StatesController < ApplicationController
    before_action :set_state, only: [:show, :edit, :update, :destroy]
    before_action :authenticate_user!
    load_and_authorize_resource except: [:create]

    # GET /states
    def index
      @states = State.all.order(:name)
    end

    # GET /states/1
    def show
    end

    # GET /states/new
    def new
      @state = State.new
    end

    # GET /states/1/edit
    def edit
    end

    # POST /states
    def create
      authorize! :create, @state
      @state = State.new(state_params)

      if @state.save
        redirect_to @state, notice: 'State was successfully created.'
      else
        render :new
      end
    end

    # PATCH/PUT /states/1
    def update
      if @state.update(state_params)
        redirect_to @state, notice: 'State was successfully updated.'
      else
        render :edit
      end
    end

    # DELETE /states/1
    def destroy
      @state.destroy
      redirect_to states_url, notice: 'State was successfully destroyed.'
    end

    private
    # Use callbacks to share common setup or constraints between actions.
    def set_state
      @state = State.find(params[:id])
    end

    # Only allow a trusted parameter "white list" through.
    def state_params
      params.require(:geography_state).permit(:name, :initials)
    end
  end
end
